<?php

namespace apexl\Io\modules\formbuilder\includes;

class textareaField extends formField
{
    public const NAME = 'textarea';

    public function __construct($name)
    {
        parent::__construct($name, self::NAME);
    }

    public function enableWysiwyg(): textareaField
    {
        $this->field->enable_editor = true;

        return $this;
    }

    public function setRows($rows): textareaField
    {
        $this->field->rows = $rows;

        return $this;
    }
}
