<?php

namespace apexl\Io\modules\formbuilder;

use apexl\Io\includes\Module;
use apexl\Io\includes\System;

class formbuilderModule extends Module
{
    public function __construct()
    {
        parent::__construct();
    }

    public function routes()
    {
    }

    public function schema()
    {
        return System::loadSchema(__DIR__.'/schema/schema.json');
    }
}
