<?php

namespace apexl\Io\modules\formbuilder\includes;

class markupField extends formField
{
    public function __construct($name, $content = '')
    {
        parent::__construct($name, 'markup');
        $this->setValue($content);
    }
}
