<?php

namespace apexl\Io\modules\formbuilder\includes;

class radioGroupField extends selectField
{
    public function __construct($name, $options = [])
    {
        parent::__construct($name, $options, 'radioGroup');
    }
}
